pub struct FileContents { /* private fields */ }Expand description
Provides lazy access to the file being overridden in the sandbox and a sink for the contents of the file to override with in the sandbox.
Implementations