OverrideHomeDir

Struct OverrideHomeDir 

pub struct OverrideHomeDir {
    pub subpath: PathBuf,
    pub overrides: Option<Vec<OverrideFile<Box<dyn Override>>>>,
}
A directory under the home directory to recursively copy into the sandbox under a temporary directory rather than mapping the real one.

Fields

subpath: PathBuf

The path of the directory to copy from the host filesystem. These paths are interpreted as relative paths below the user’s home directory.

overrides: Option<Vec<OverrideFile<Box<dyn Override>>>>

Arbitrary extra settings to apply to files mapped to the sandbox

Implementations

Source

impl OverrideHomeDir

pub fn new(path_segments: impl IntoIterator<Item = impl AsRef<Path>>) -> Self

Creates a new override home directory for the given path.

pub fn with_override( &mut self, path: impl Into<PathBuf>, behavior: impl Override + 'static, ) -> &mut Self

Adds an override for the given path with the given behavior.

pub fn take(&mut self) -> Self

Helper function to get an owned OverrideHomeDir instance from a mutable reference to facilitate builder-style chaining.