#[non_exhaustive]pub enum ErrorKind {
Io {
error: Error,
additional: String,
},
NonRelativePath(PathBuf),
}Expand description
Represents the kind of error that occurred when trying to configure or construct a sandbox or execute a command inside it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
An I/O error occurred.
NonRelativePath(PathBuf)
An absolute path was provided when a relative one is needed.