Sandbox

Struct Sandbox 

pub struct Sandbox {
    pub sandbox_type: SandboxType,
    pub config: SandboxConfig,
}

Fields

sandbox_type: SandboxTypeconfig: SandboxConfig

Implementations

Source

impl Sandbox

pub const fn new(sandbox_type: SandboxType, config: SandboxConfig) -> Self

pub const fn configure() -> SandboxConfig

pub fn dry_run<'a>( self, process: &OsStr, args: impl Iterator<Item = &'a OsStr>, ) -> Result<()>

Prints the command that would have been executed instead of running it.

Errors

Returns an error if the command cannot be constructed.

pub fn exec<'a>( self, process: &OsStr, args: impl Iterator<Item = &'a OsStr>, ) -> Result<()>

Executes the sandbox using the specified process and arguments.

Errors

Returns an error if the command cannot be constructed or executed.